==> org.opennms.features.topology.app-19.0.0-20190703.204716-264-sources.jar: org/opennms/features/topology/app/internal/operations/ClearFocusOperation.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.topology.app.internal.operations;

import java.util.List;
import java.util.Set;

import org.opennms.features.topology.api.GraphContainer;
import org.opennms.features.topology.api.Operation;
import org.opennms.features.topology.api.OperationContext;
import org.opennms.features.topology.api.support.VertexHopGraphProvider;
import org.opennms.features.topology.api.topo.VertexRef;
import org.opennms.features.topology.app.internal.TopologyUI;

/**
 * Removes all elements from focus.
 *
 * @author mvrueden
 */
public class ClearFocusOperation implements Operation {

    @Override
    public void execute(List<VertexRef> targets, OperationContext operationContext) {
        final GraphContainer graphContainer = operationContext.getGraphContainer();
        final Set<VertexHopGraphProvider.VertexHopCriteria> focusCriteria = graphContainer.findCriteria(VertexHopGraphProvider.VertexHopCriteria.class);
        for (VertexHopGraphProvider.VertexHopCriteria eachFocusCriteria : focusCriteria) {
            graphContainer.removeCriteria(eachFocusCriteria);
        }
        graphContainer.redoLayout();
    }

    @Override
    public boolean display(List<VertexRef> targets, OperationContext operationContext) {
        return (operationContext.getDisplayLocation() == OperationContext.DisplayLocation.MENUBAR)
                || (targets != null && targets.size() == 0);
    }

    @Override
    public boolean enabled(List<VertexRef> targets, OperationContext operationContext) {
        return true; // always enabled
    }

    @Override
    public String getId() {
        return "ClearFocus";
    }
    public void execute(final GraphContainer graphContainer) {
        graphContainer.getBaseTopology().refresh();
        graphContainer.setDirty(true);
        graphContainer.redoLayout();
        TopologyUI.getCurrent().markAsDirtyRecursive();
    }
}

==> org.opennms.features.topology.app-27.0.0-20200530.152008-31-sources.jar: org/opennms/features/topology/app/internal/operations/ClearFocusOperation.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.topology.app.internal.operations;

import java.util.List;
import java.util.Set;

import org.opennms.features.topology.api.GraphContainer;
import org.opennms.features.topology.api.Operation;
import org.opennms.features.topology.api.OperationContext;
import org.opennms.features.topology.api.support.hops.VertexHopCriteria;
import org.opennms.features.topology.api.topo.VertexRef;
import org.opennms.features.topology.app.internal.TopologyUI;

/**
 * Removes all elements from focus.
 *
 * @author mvrueden
 */
public class ClearFocusOperation implements Operation {

    @Override
    public void execute(List<VertexRef> targets, OperationContext operationContext) {
        final GraphContainer graphContainer = operationContext.getGraphContainer();
        final Set<VertexHopCriteria> focusCriteria = graphContainer.findCriteria(VertexHopCriteria.class);
        for (VertexHopCriteria eachFocusCriteria : focusCriteria) {
            graphContainer.removeCriteria(eachFocusCriteria);
        }
        graphContainer.redoLayout();
    }

    @Override
    public boolean display(List<VertexRef> targets, OperationContext operationContext) {
        return (operationContext.getDisplayLocation() == OperationContext.DisplayLocation.MENUBAR)
                || (targets != null && targets.size() == 0);
    }

    @Override
    public boolean enabled(List<VertexRef> targets, OperationContext operationContext) {
        return true; // always enabled
    }

    @Override
    public String getId() {
        return "ClearFocus";
    }
    public void execute(final GraphContainer graphContainer) {
        graphContainer.setDirty(true);
        graphContainer.redoLayout();
        TopologyUI.getCurrent().markAsDirtyRecursive();
    }
}
